Go
====

This file contains examples for working with **auth_headers_builder** library.

### Examples:

- GET request:

        package main
        
        import (
            "fmt"
            "io/ioutil"
            "net/http"
        )
        
        func main() {
            apiKey := "MY_API_KEY"
            apiSecret := "MY_API_SECRET"
            httpMethod := "GET"
            url := "https://www.example.com/resources"
            
            authHeaders, err := GenerateAuthHeaders(apiKey, apiSecret, httpMethod, url)
            if err != nil {
                panic(err)
            }
            
            req, err := http.NewRequest(httpMethod, url, nil)
            if err != nil {
                panic(err)
            }
    
            for name, value := range authHeaders {
                req.Header.Add(name, value)
            }
    
            resp, err := http.DefaultClient.Do(req)
            if err != nil {
                panic(err)
            }
            
            defer resp.Body.Close()
            
            fmt.Println("Status:", resp.Status)
            
            body, err := ioutil.ReadAll(resp.Body)
            if err != nil {
                panic(err)
            }
            
            fmt.Println("Body:", string(body))
        }

- POST request:

        package main
    
        import (
            "fmt"
            "io/ioutil"
            "net/http"
            "strings"
        )
    
        func main() {
            apiKey := "MY_API_KEY"
            apiSecret := "MY_API_SECRET"
            httpMethod := "POST"
            url := "https://www.example.com/resources"
            contentType := "application/json"
            payload := "REQUEST_BODY"
    
            authHeaders, err := GenerateAuthHeadersWithContent(apiKey, apiSecret, httpMethod, url, contentType, payload)
            if err != nil {
                panic(err)
            }
    
            req, err := http.NewRequest(httpMethod, url, strings.NewReader(payload))
            if err != nil {
                panic(err)
            }
    
            for name, value := range authHeaders {
                req.Header.Add(name, value)
            }
    
            resp, err := http.DefaultClient.Do(req)
            if err != nil {
                panic(err)
            }
    
            defer resp.Body.Close()
    
            fmt.Println("Status:", resp.Status)
    
            body, err := ioutil.ReadAll(resp.Body)
            if err != nil {
                panic(err)
            }
    
            fmt.Println("Body:", string(body))
        }

- PUT request:

        package main

        import (
            "fmt"
            "io/ioutil"
            "net/http"
            "strings"
        )

        func main() {
            apiKey := "MY_API_KEY"
            apiSecret := "MY_API_SECRET"
            httpMethod := "PUT"
            url := "https://www.example.com/resources"
            contentType := "application/json"
            payload := "REQUEST_BODY"
        
            authHeaders, err := GenerateAuthHeadersWithContent(apiKey, apiSecret, httpMethod, url, contentType, payload)
            if err != nil {
                panic(err)
            }

            req, err := http.NewRequest(httpMethod, url, strings.NewReader(payload))
            if err != nil {
                panic(err)
            }
        
            for name, value := range authHeaders {
                req.Header.Add(name, value)
            }
        
            resp, err := http.DefaultClient.Do(req)
            if err != nil {
                panic(err)
            }
        
            defer resp.Body.Close()
        
            fmt.Println("Status:", resp.Status)
        
            body, err := ioutil.ReadAll(resp.Body)
            if err != nil {
                panic(err)
            }
        
            fmt.Println("Body:", string(body))
        }

- DELETE request:

        package main

        import (
            "fmt"
            "io/ioutil"
            "net/http"
        )
        
        func main() {
            apiKey := "MY_API_KEY"
            apiSecret := "MY_API_SECRET"
            httpMethod := "DELETE"
            url := "https://www.example.com/resources"
        
            authHeaders, err := GenerateAuthHeaders(apiKey, apiSecret, httpMethod, url)
            if err != nil {
                panic(err)
            }
        
            req, err := http.NewRequest(httpMethod, url, nil)
            if err != nil {
                panic(err)
            }
        
            for name, value := range authHeaders {
                req.Header.Add(name, value)
            }
        
            resp, err := http.DefaultClient.Do(req)
            if err != nil {
                panic(err)
            }
        
            defer resp.Body.Close()
        
            fmt.Println("Status:", resp.Status)
        
            body, err := ioutil.ReadAll(resp.Body)
            if err != nil {
                panic(err)
            }
        
            fmt.Println("Body:", string(body))
        }
