PHP
====

This file contains prerequisites and examples for working with **AuthHeadersBuilder** library using PHP `cURL` extension.

### Prerequisites:

* The request examples below are based on PHP `cURL` extension.

    To use `cURL` extension:

    * open `<PHP_HOME>\php.ini` file
    * find

            ;extension=curl

    * uncomment it (remove `;` at the beginning)


* If the following warning appears

        Warning: PHP Startup: Unable to load dynamic library 'curl'

    Please do the next steps:

    * open `<PHP_HOME>\php.ini` file
    * find

            ; Directory in which the loadable extensions (modules) reside.
            ; https://php.net/extension-dir
            ;extension_dir = "./"
            ; On windows:
            ;extension_dir = "ext"

    * uncomment (remove `;` at the beginning) appropriate `extension_dir` (tested on Windows)


* If the following error appears

        cURL Error: SSL certificate problem: self signed certificate in certificate chain

    Please do the next steps:

    * Download `cacert.pem` from http://curl.haxx.se/docs/caextract.html
    * There are two options how to specify a path to `cacert.pem` file:
        * Option 1:
            * open `<PHP_HOME>\php.ini` file
            * find

                    ;curl.cainfo =

            * uncomment it and set absolute path to `cacert.pem` file. For example,

                    curl.cainfo = C:\Program Files\php-8.1.6\cacert.pem

        * Option 2:
            * find `curl_setopt_array` method call in the examples below and set absolute path to `cacert.pem` file
              using `CURLOPT_CAINFO` option. For example,

                    curl_setopt_array(
                        $curl,
                        [
                            CURLOPT_CAINFO => "C:\Program Files\php-8.1.6\cacert.pem",
                            CURLOPT_RETURNTRANSFER => true,
                            CURLOPT_CUSTOMREQUEST => $httpMethod,
                            CURLOPT_URL => $url,
                            CURLOPT_POSTFIELDS  => $payload,
                            CURLOPT_HTTPHEADER => $curlAuthHeaders,
                        ]);

### Examples:

- GET request:

        <?php
        require_once 'AuthHeadersBuilder.php';
        
        $apiKey = 'MY_API_KEY';
        $apiSecret = 'MY_API_SECRET';
        $httpMethod = 'GET';
        $url = 'https://www.example.com/resources';
        
        $authHeaders = AuthHeadersBuilder::generateAuthHeaders($apiKey, $apiSecret, $httpMethod, $url);
        
        $curlAuthHeaders = [];
        $i = 0;
        foreach ($authHeaders as $name => $value) {
            $curlAuthHeaders[$i++] = "$name: $value";
        }
        
        $curl = curl_init();
        
        curl_setopt_array(
            $curl,
            [
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_CUSTOMREQUEST => $httpMethod,
                CURLOPT_URL => $url,
                CURLOPT_HTTPHEADER => $curlAuthHeaders,
            ]);
        
        $response = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        $err = curl_error($curl);
        
        curl_close($curl);
        
        if ($err) {
            echo "cURL Error: $err\n";
        } else {
            echo "Status: $httpCode\n";
            echo "Body: $response\n";
        }

- POST request:

        <?php
        require_once 'AuthHeadersBuilder.php';
        
        $apiKey = 'MY_API_KEY';
        $apiSecret = 'MY_API_SECRET';
        $httpMethod = 'POST';
        $url = 'https://www.example.com/resources';
        $contentType = 'application/json';
        $payload = 'REQUEST_BODY';
        
        $authHeaders = AuthHeadersBuilder::generateAuthHeaders($apiKey, $apiSecret, $httpMethod, $url, $contentType, $payload);
        
        $curlAuthHeaders = [];
        $i = 0;
        foreach ($authHeaders as $name => $value) {
            $curlAuthHeaders[$i++] = "$name: $value";
        }
        
        $curl = curl_init();
        
        curl_setopt_array(
            $curl,
            [
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_CUSTOMREQUEST => $httpMethod,
                CURLOPT_URL => $url,
                CURLOPT_POSTFIELDS  => $payload,
                CURLOPT_HTTPHEADER => $curlAuthHeaders,
            ]);
        
        $response = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        $err = curl_error($curl);
        
        curl_close($curl);
        
        if ($err) {
            echo "cURL Error: $err\n";
        } else {
            echo "Status: $httpCode\n";
            echo "Body: $response\n";
        }

- PUT request:

        <?php
        require_once 'AuthHeadersBuilder.php';
        
        $apiKey = 'MY_API_KEY';
        $apiSecret = 'MY_API_SECRET';
        $httpMethod = 'PUT';
        $url = 'https://www.example.com/resources';
        $contentType = 'application/json';
        $payload = 'REQUEST_BODY';
        
        $authHeaders = AuthHeadersBuilder::generateAuthHeaders($apiKey, $apiSecret, $httpMethod, $url, $contentType, $payload);
        
        $curlAuthHeaders = [];
        $i = 0;
        foreach ($authHeaders as $name => $value) {
            $curlAuthHeaders[$i++] = "$name: $value";
        }
        
        $curl = curl_init();
        
        curl_setopt_array(
            $curl,
            [
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_CUSTOMREQUEST => $httpMethod,
                CURLOPT_URL => $url,
                CURLOPT_POSTFIELDS  => $payload,
                CURLOPT_HTTPHEADER => $curlAuthHeaders,
            ]);
        
        $response = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        $err = curl_error($curl);
        
        curl_close($curl);
        
        if ($err) {
            echo "cURL Error: $err\n";
        } else {
            echo "Status: $httpCode\n";
            echo "Body: $response\n";
        }

- DELETE request:

        <?php
        require_once 'AuthHeadersBuilder.php';
        
        $apiKey = 'MY_API_KEY';
        $apiSecret = 'MY_API_SECRET';
        $httpMethod = 'DELETE';
        $url = 'https://www.example.com/resources';
        
        $authHeaders = AuthHeadersBuilder::generateAuthHeaders($apiKey, $apiSecret, $httpMethod, $url);
        
        $curlAuthHeaders = [];
        $i = 0;
        foreach ($authHeaders as $name => $value) {
            $curlAuthHeaders[$i++] = "$name: $value";
        }
        
        $curl = curl_init();
        
        curl_setopt_array(
            $curl,
            [
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_CUSTOMREQUEST => $httpMethod,
                CURLOPT_URL => $url,
                CURLOPT_HTTPHEADER => $curlAuthHeaders,
            ]);
        
        $response = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        $err = curl_error($curl);
        
        curl_close($curl);
        
        if ($err) {
            echo "cURL Error: $err\n";
        } else {
            echo "Status: $httpCode\n";
            echo "Body: $response\n";
        }
